<?php

namespace Focus\Salesmanager\Policies;

use Litepie\User\Contracts\UserPolicy;
use Focus\Salesmanager\Models\Salesmanager;

class SalesmanagerPolicy
{

    /**
     * Determine if the given user can view the salesmanager.
     *
     * @param UserPolicy $user
     * @param Salesmanager $salesmanager
     *
     * @return bool
     */
    public function view(UserPolicy $user, Salesmanager $salesmanager)
    {
        if ($user->canDo('salesmanager.salesmanager.view') && $user->isAdmin()) {
            return true;
        }

        return $salesmanager->user_id == user_id() && $salesmanager->user_type == user_type();
    }

    /**
     * Determine if the given user can create a salesmanager.
     *
     * @param UserPolicy $user
     * @param Salesmanager $salesmanager
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('salesmanager.salesmanager.create');
    }

    /**
     * Determine if the given user can update the given salesmanager.
     *
     * @param UserPolicy $user
     * @param Salesmanager $salesmanager
     *
     * @return bool
     */
    public function update(UserPolicy $user, Salesmanager $salesmanager)
    {
        if ($user->canDo('salesmanager.salesmanager.edit') && $user->isAdmin()) {
            return true;
        }

        return $salesmanager->user_id == user_id() && $salesmanager->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given salesmanager.
     *
     * @param UserPolicy $user
     * @param Salesmanager $salesmanager
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Salesmanager $salesmanager)
    {
        return $salesmanager->user_id == user_id() && $salesmanager->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given salesmanager.
     *
     * @param UserPolicy $user
     * @param Salesmanager $salesmanager
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Salesmanager $salesmanager)
    {
        if ($user->canDo('salesmanager.salesmanager.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given salesmanager.
     *
     * @param UserPolicy $user
     * @param Salesmanager $salesmanager
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Salesmanager $salesmanager)
    {
        if ($user->canDo('salesmanager.salesmanager.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
