<?php

namespace Focus\Salesmanager\Providers;

use Illuminate\Support\ServiceProvider;

class SalesmanagerServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'salesmanager');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'salesmanager');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('focus.salesmanager', function ($app) {
            return $this->app->make('Focus\Salesmanager\Salesmanager');
        });

                // Bind Salesmanager to repository
        $this->app->bind(
            'Focus\Salesmanager\Interfaces\SalesmanagerRepositoryInterface',
            \Focus\Salesmanager\Repositories\Eloquent\SalesmanagerRepository::class
        );

        $this->app->register(\Focus\Salesmanager\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Focus\Salesmanager\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['focus.salesmanager'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('focus/salesmanager.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/salesmanager')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/salesmanager')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
